@@ -6,11 +6,10 @@ use ::pnet::datalink::{self, Config, NetworkInterface};
 use ::std::io::{self, ErrorKind, Write};
 use ::tokio::runtime::Runtime;
 
+use ::std::net::Ipv4Addr;
 use ::std::time;
 
 use crate::os::errors::GetInterfaceErrorKind;
-#[cfg(not(target_os = "windows"))]
-use signal_hook::iterator::Signals;
 
 #[cfg(target_os = "linux")]
 use crate::os::linux::get_open_sockets;
@@ -21,12 +20,9 @@ use crate::os::windows::get_open_sockets;
 
 use crate::{network::dns, OsInputOutput};
 
-pub type OnSigWinch = dyn Fn(Box<dyn Fn()>) + Send;
-pub type SigCleanup = dyn Fn() + Send;
+pub struct TerminalEvents;
 
-pub struct KeyboardEvents;
-
-impl Iterator for KeyboardEvents {
+impl Iterator for TerminalEvents {
     type Item = Event;
     fn next(&mut self) -> Option<Event> {
         match read() {
@@ -36,7 +32,7 @@ impl Iterator for KeyboardEvents {
     }
 }
 
-fn get_datalink_channel(
+pub(crate) fn get_datalink_channel(
     interface: &NetworkInterface,
 ) -> Result<Box<dyn DataLinkReceiver>, GetInterfaceErrorKind> {
     let mut config = Config::default();
@@ -67,35 +63,6 @@ fn get_interface(interface_name: &str) -> Option<NetworkInterface> {
         .find(|iface| iface.name == interface_name)
 }
 
-#[cfg(not(target_os = "windows"))]
-fn sigwinch() -> (Box<OnSigWinch>, Box<SigCleanup>) {
-    let signals = Signals::new(&[signal_hook::SIGWINCH]).unwrap();
-    let on_winch = {
-        let signals = signals.clone();
-        move |cb: Box<dyn Fn()>| {
-            for signal in signals.forever() {
-                match signal {
-                    signal_hook::SIGWINCH => cb(),
-                    _ => unreachable!(),
-                }
-            }
-        }
-    };
-    let cleanup = move || {
-        signals.close();
-    };
-    (Box::new(on_winch), Box::new(cleanup))
-}
-
-#[cfg(any(target_os = "windows"))]
-fn sigwinch() -> (Box<OnSigWinch>, Box<SigCleanup>) {
-    let on_winch = { move |_cb: Box<dyn Fn()>| {} };
-    let cleanup = move || {
-        println!("Fake signal cleanup");
-    };
-    (Box::new(on_winch), Box::new(cleanup))
-}
-
 fn create_write_to_stdout() -> Box<dyn FnMut(String) + Send> {
     Box::new({
         let mut stdout = io::stdout();
@@ -181,6 +148,7 @@ where
 pub fn get_input(
     interface_name: &Option<String>,
     resolve: bool,
+    dns_server: &Option<Ipv4Addr>,
 ) -> Result<OsInputOutput, failure::Error> {
     let network_interfaces = if let Some(name) = interface_name {
         match get_interface(&name) {
@@ -231,15 +199,18 @@ pub fn get_input(
         failure::bail!("Failed to find any network interface to listen on.");
     }
 
-    let keyboard_events = Box::new(KeyboardEvents);
+    let keyboard_events = Box::new(TerminalEvents);
     let write_to_stdout = create_write_to_stdout();
-    let (on_winch, cleanup) = sigwinch();
     let dns_client = if resolve {
         let mut runtime = Runtime::new()?;
-        let resolver = match runtime.block_on(dns::Resolver::new(runtime.handle().clone())) {
-            Ok(resolver) => resolver,
-            Err(_) => failure::bail!("Could not initialize the DNS resolver. Are you offline?"),
-        };
+        let resolver =
+            match runtime.block_on(dns::Resolver::new(runtime.handle().clone(), dns_server)) {
+                Ok(resolver) => resolver,
+                Err(err) => failure::bail!(
+                    "Could not initialize the DNS resolver. Are you offline?\n\nReason: {:?}",
+                    err
+                ),
+            };
         let dns_client = dns::Client::new(resolver, runtime)?;
         Some(dns_client)
     } else {
@@ -250,10 +221,8 @@ pub fn get_input(
         network_interfaces,
         network_frames: available_network_frames,
         get_open_sockets,
-        keyboard_events,
+        terminal_events: keyboard_events,
         dns_client,
-        on_winch,
-        cleanup,
         write_to_stdout,
     })
 }
