@@ -1,6 +1,6 @@
 use crate::tests::fakes::TerminalEvent::*;
 use crate::tests::fakes::{
-    create_fake_dns_client, create_fake_on_winch, get_interfaces, get_open_sockets, NetworkFrames,
+    create_fake_dns_client, get_interfaces, get_open_sockets, NetworkFrames,
 };
 
 use ::insta::assert_snapshot;
@@ -10,13 +10,13 @@ use ::std::net::IpAddr;
 
 use crate::tests::cases::test_utils::{
     build_tcp_packet, opts_ui, os_input_output, os_input_output_factory, sample_frames,
-    sleep_and_quit_events, test_backend_factory,
+    sleep_and_quit_events, sleep_resize_and_quit_events, test_backend_factory,
 };
 use ::crossterm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
 use pnet::datalink::DataLinkReceiver;
 use std::iter;
 
-use crate::tests::fakes::KeyboardEvents;
+use crate::tests::fakes::TerminalEvents;
 
 use crate::{start, Opt, OsInputOutput, RenderOpts};
 
@@ -32,7 +32,9 @@ fn basic_startup() {
     start(backend, os_input, opts);
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
-    let expected_terminal_events = vec![Clear, HideCursor, Draw, Flush, Clear, ShowCursor];
+    let expected_terminal_events = vec![
+        Clear, HideCursor, Draw, HideCursor, Flush, Clear, ShowCursor,
+    ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
         &expected_terminal_events[..]
@@ -81,14 +83,15 @@ fn pause_by_space() {
         code: KeyCode::Char('c'),
     })));
 
-    let events = Box::new(KeyboardEvents::new(events));
+    let events = Box::new(TerminalEvents::new(events));
     let os_input = os_input_output_factory(network_frames, None, None, events);
     let (terminal_events, terminal_draw_events, backend) = test_backend_factory(190, 50);
     let opts = opts_ui();
     start(backend, os_input, opts);
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -136,15 +139,15 @@ fn rearranged_by_tab() {
         code: KeyCode::Char('c'),
     })));
 
-    let events = Box::new(KeyboardEvents::new(events));
+    let events = Box::new(TerminalEvents::new(events));
     let os_input = os_input_output_factory(network_frames, None, None, events);
     let (terminal_events, terminal_draw_events, backend) = test_backend_factory(190, 50);
     let opts = opts_ui();
     start(backend, os_input, opts);
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Draw, Flush, Draw, Flush, Clear,
-        ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -171,6 +174,7 @@ fn basic_only_processes() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: false,
             connections: false,
@@ -197,6 +201,7 @@ fn basic_processes_with_dns_queries() {
         raw: false,
         no_resolve: false,
         show_dns: true,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: false,
             connections: false,
@@ -223,6 +228,7 @@ fn basic_only_connections() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: false,
             connections: true,
@@ -249,6 +255,7 @@ fn basic_only_addresses() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: true,
             connections: false,
@@ -273,6 +280,7 @@ fn two_packets_only_processes() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: false,
             connections: false,
@@ -298,6 +306,7 @@ fn two_packets_only_connections() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: false,
             connections: true,
@@ -323,6 +332,7 @@ fn two_packets_only_addresses() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: true,
             connections: false,
@@ -350,6 +360,7 @@ fn two_windows_split_horizontally() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: true,
             connections: true,
@@ -376,6 +387,7 @@ fn two_windows_split_vertically() {
         raw: false,
         no_resolve: false,
         show_dns: false,
+        dns_server: None,
         render_opts: RenderOpts {
             addresses: true,
             connections: true,
@@ -405,7 +417,7 @@ fn one_packet_of_traffic() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -428,7 +440,7 @@ fn bi_directional_traffic() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -466,7 +478,7 @@ fn multiple_packets_of_traffic_from_different_connections() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -504,7 +516,7 @@ fn multiple_packets_of_traffic_from_single_connection() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -542,7 +554,7 @@ fn one_process_with_multiple_connections() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -594,7 +606,7 @@ fn multiple_processes_with_multiple_connections() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -632,7 +644,7 @@ fn multiple_connections_from_remote_address() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -672,7 +684,8 @@ fn sustained_traffic_from_one_process() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -713,7 +726,8 @@ fn sustained_traffic_from_one_process_total() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -767,7 +781,8 @@ fn sustained_traffic_from_multiple_processes() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -822,7 +837,8 @@ fn sustained_traffic_from_multiple_processes_total() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -904,7 +920,8 @@ fn sustained_traffic_from_multiple_processes_bi_directional() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -987,7 +1004,8 @@ fn sustained_traffic_from_multiple_processes_bi_directional_total() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1077,18 +1095,14 @@ fn traffic_with_host_names() {
         String::from("i-like-cheese.com"),
     );
     let dns_client = create_fake_dns_client(ips_to_hostnames);
-    let on_winch = create_fake_on_winch(false);
-    let cleanup = Box::new(|| {});
     let write_to_stdout = Box::new(move |_output: String| {});
 
     let os_input = OsInputOutput {
         network_interfaces: get_interfaces(),
         network_frames,
         get_open_sockets,
-        keyboard_events: sleep_and_quit_events(3),
+        terminal_events: sleep_and_quit_events(3),
         dns_client,
-        on_winch,
-        cleanup,
         write_to_stdout,
     };
     let opts = opts_ui();
@@ -1096,7 +1110,8 @@ fn traffic_with_host_names() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1186,18 +1201,14 @@ fn truncate_long_hostnames() {
         String::from("i-like-cheese.com"),
     );
     let dns_client = create_fake_dns_client(ips_to_hostnames);
-    let on_winch = create_fake_on_winch(false);
-    let cleanup = Box::new(|| {});
     let write_to_stdout = Box::new(move |_output: String| {});
 
     let os_input = OsInputOutput {
         network_interfaces: get_interfaces(),
         network_frames,
         get_open_sockets,
-        keyboard_events: sleep_and_quit_events(3),
+        terminal_events: sleep_and_quit_events(3),
         dns_client,
-        on_winch,
-        cleanup,
         write_to_stdout,
     };
     let opts = opts_ui();
@@ -1205,7 +1216,8 @@ fn truncate_long_hostnames() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1294,18 +1306,14 @@ fn no_resolve_mode() {
         String::from("i-like-cheese.com"),
     );
     let dns_client = None;
-    let on_winch = create_fake_on_winch(false);
-    let cleanup = Box::new(|| {});
     let write_to_stdout = Box::new(move |_output: String| {});
 
     let os_input = OsInputOutput {
         network_interfaces: get_interfaces(),
         network_frames,
         get_open_sockets,
-        keyboard_events: sleep_and_quit_events(3),
+        terminal_events: sleep_and_quit_events(3),
         dns_client,
-        on_winch,
-        cleanup,
         write_to_stdout,
     };
     let opts = opts_ui();
@@ -1313,7 +1321,8 @@ fn no_resolve_mode() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1338,18 +1347,14 @@ fn traffic_with_winch_event() {
     let (terminal_events, terminal_draw_events, backend) = test_backend_factory(190, 50);
 
     let dns_client = create_fake_dns_client(HashMap::new());
-    let on_winch = create_fake_on_winch(true);
-    let cleanup = Box::new(|| {});
     let write_to_stdout = Box::new(move |_output: String| {});
 
     let os_input = OsInputOutput {
         network_interfaces: get_interfaces(),
         network_frames,
         get_open_sockets,
-        keyboard_events: sleep_and_quit_events(2),
+        terminal_events: sleep_resize_and_quit_events(2),
         dns_client,
-        on_winch,
-        cleanup,
         write_to_stdout,
     };
     let opts = opts_ui();
@@ -1357,7 +1362,8 @@ fn traffic_with_winch_event() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Draw, HideCursor,
+        Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1411,7 +1417,7 @@ fn layout_full_width_under_30_height() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1463,7 +1469,7 @@ fn layout_under_120_width_full_height() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1514,7 +1520,7 @@ fn layout_under_120_width_under_30_height() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1565,7 +1571,7 @@ fn layout_under_50_width_under_50_height() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
@@ -1616,7 +1622,7 @@ fn layout_under_70_width_under_30_height() {
     let terminal_draw_events_mirror = terminal_draw_events.lock().unwrap();
 
     let expected_terminal_events = vec![
-        Clear, HideCursor, Draw, Flush, Draw, Flush, Clear, ShowCursor,
+        Clear, HideCursor, Draw, HideCursor, Flush, Draw, HideCursor, Flush, Clear, ShowCursor,
     ];
     assert_eq!(
         &terminal_events.lock().unwrap()[..],
